__title__ = 'fastani'
__description__ = 'A wrapper to the FastANI program.'
__url__ = 'https://github.com/aaronmussig/FastANI'
__version__ = '1.1.0'
__author__ = 'Aaron Mussig'
__author_email__ = 'aaronmussig@gmail.com'
__license__ = 'GNU AGPLv3'
__bug_url__ = 'https://github.com/aaronmussig/FastANI'
__doc_url__ = 'https://github.com/aaronmussig/FastANI'
__src_url__ = 'https://github.com/aaronmussig/FastANI'

from fastani.fastani import fastani
